#ifndef NT2_INCLUDE_FUNCTIONS_ALMOST_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ALMOST_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/almost_equal.hpp>

#endif
